/**
 * Sonatype Nexus (TM) Open Source Version.
 * Copyright (c) 2008 Sonatype, Inc. All rights reserved.
 * Includes the third-party code listed at http://nexus.sonatype.org/dev/attributions.html
 * This program is licensed to you under Version 3 only of the GNU General Public License as published by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License Version 3 for more details.
 * You should have received a copy of the GNU General Public License Version 3 along with this program.
 * If not, see http://www.gnu.org/licenses/.
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc.
 * "Sonatype" and "Sonatype Nexus" are trademarks of Sonatype, Inc.
 */
package org.sonatype.nexus.tasks;

import java.util.List;

import org.codehaus.plexus.component.annotations.Component;
import org.codehaus.plexus.component.annotations.Requirement;
import org.sonatype.nexus.feeds.FeedRecorder;
import org.sonatype.nexus.scheduling.AbstractNexusRepositoriesPathAwareTask;
import org.sonatype.nexus.tasks.descriptors.OptimizeIndexTaskDescriptor;
import org.sonatype.nexus.tasks.descriptors.ReindexTaskDescriptor;
import org.sonatype.scheduling.SchedulerTask;

/**
 * Reindex task.
 * 
 * @author cstamas
 */
@Component( role = SchedulerTask.class, hint = ReindexTaskDescriptor.ID, instantiationStrategy = "per-lookup" )
public class ReindexTask
    extends AbstractNexusRepositoriesPathAwareTask<Object>
{

    @Requirement( role = ReindexTaskHandler.class )
    private List<ReindexTaskHandler> handlers;

    @Override
    protected String getRepositoryFieldId()
    {
        return OptimizeIndexTaskDescriptor.REPO_OR_GROUP_FIELD_ID;
    }

    @Override
    protected String getRepositoryPathFieldId()
    {
        return null;
    }

    public boolean getFullReindex()
    {
        boolean fullReindex = new Boolean( getParameter( ReindexTaskDescriptor.FULL_REINDEX_FIELD_ID ) );
        return fullReindex;
    }

    public void setFullReindex( boolean fullReindex )
    {
        getParameters().put( ReindexTaskDescriptor.FULL_REINDEX_FIELD_ID, String.valueOf( fullReindex ) );
    }

    @Override
    public Object doRun()
        throws Exception
    {
        for ( ReindexTaskHandler handler : handlers )
        {
            if ( getRepositoryId() != null )
            {
                handler.reindexRepository( getRepositoryId(), getResourceStorePath(), getFullReindex() );
            }
            else if ( getRepositoryGroupId() != null )
            {
                handler.reindexRepositoryGroup( getRepositoryGroupId(), getResourceStorePath(), getFullReindex() );
            }
            else
            {
                handler.reindexAllRepositories( getResourceStorePath(), getFullReindex() );
            }
        }

        return null;
    }

    @Override
    protected String getAction()
    {
        return FeedRecorder.SYSTEM_REINDEX_ACTION;
    }

    @Override
    protected String getMessage()
    {
        if ( getRepositoryGroupId() != null )
        {
            return "Reindexing repository group " + getRepositoryGroupName() + " from path " + getResourceStorePath()
                + " and below.";
        }
        else if ( getRepositoryId() != null )
        {
            return "Reindexing repository " + getRepositoryName() + " from path " + getResourceStorePath()
                + " and below.";
        }
        else
        {
            return "Reindexing all registered repositories";
        }
    }

}
